@@ -16,19 +16,14 @@ class IntensiveThread(threading.Thread):
         IntensityLevel.HIGH: 1000000000
     }
 
-    def __init__(self, test_id):
+    def __init__(self):
         super().__init__()
-        self.intensity = IntensityLevel(test_id).name
-        self.number = self.numbers[test_id]
 
     def run(self):
         """
         Runs an intensive task based on the intensity level
         :return:
         """
-        #print(f"Doing a {self.intensity} intensive task. ID: {self.native_id}")
-
-        for i in range(self.number):
-            continue
-
-        # print("Done doing some intensive task")
+        with open("intensive_output.txt", 'w') as f:
+            for i in range(10000):
+                f.write(str("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"))
