@@ -1,7 +1,11 @@
+from flockai.PyCatascopia.probelib.ProcessProbe import ProcessProbe
 from flockai.models.drones.autopilot_controlled_drone import AutopilotControlledDrone
 from flockai.models.drones.keyboard_controller_drone import KeyboardControlledDrone
+from flockai.models.sensors.humidity import HumiditySensor
+from flockai.models.sensors.temperature import TemperatureSensor
 from flockai.utils.string_generator import StringGenerator
 from flockai.models.devices.device_enums import EnableableDevice, NonEnableableDevice, MotorDevice
+from flockai.utils.intensive_thread import IntensiveThread
 
 
 class KeyboardMavic2DJI(KeyboardControlledDrone):
@@ -9,8 +13,20 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
     A Keyboard Controlled Mavic2DJI
     """
 
-    def __init__(self, devices):
+    def __init__(self, devices, probes=None):
+        self.P_COMM = 8.4
+        self.DJI_A3_FC = 8
+        self.RASPBERRY_PI_4B_IDLE = 4
+        self.RASPBERRY_PI_4B_ACTIVE = 8
         super().__init__(devices)
+        self.probes = probes
+        self._activate_probes()
+
+    def _activate_probes(self):
+        if self.probes:
+            for key, probe in self.probes.items():
+                probe.activate()
+                print(f'{key} probe activated')
 
     def send_msg(self, msg, emitter_devices: list):
         """
@@ -19,12 +35,21 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         :param msg: The message to send
         :return: None
         """
+
+        total_time = 0
+        cpu_probe: ProcessProbe = self.probes['cpu']
+
         for emitter in emitter_devices:
             if emitter not in self.devices:
                 print(f"The specified emitter device is not found: {emitter}")
-                return
+                return 0
             f_emitter = self.devices[emitter]['device']
+            t1 = cpu_probe.probe_alive_time.get_val()
             f_emitter.send(msg.encode('utf-8'))
+            t2 = cpu_probe.probe_alive_time.get_val()
+            total_time += t2 - t1
+
+        return total_time
 
     def receive_msgs(self, receiver_devices: list):
         """
@@ -32,16 +57,25 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         :param receiver_devices: The receiver device name as a string
         :return: None
         """
+        cpu_probe: ProcessProbe = self.probes['cpu']
+        total_time = 0
+        messages = []
+
         for receiver in receiver_devices:
             if receiver not in self.devices:
                 print(f"The specified receiver device is not found: {receiver}")
-                return
+                return [], 0
 
             f_receiver = self.devices[receiver]['device']
             while f_receiver.getQueueLength() > 0:
+                t1 = cpu_probe.probe_alive_time.get_val()
                 message_received = f_receiver.getData().decode('utf-8')
+                messages.append(message_received)
                 f_receiver.nextPacket()
-                yield message_received
+                t2 = cpu_probe.probe_alive_time.get_val()
+                total_time += t2 - t1
+
+        return messages, total_time
 
     def blink_led_lights(self, led_devices: list):
         """
@@ -73,6 +107,13 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             if self.devices[device_name]['type'] == EnableableDevice.RECEIVER:
                 receiver_devices.append(device_name)
 
+        # self._activate_probes()
+        cpu_probe: ProcessProbe = self.probes['cpu']
+        total_energy = 0
+        net_transaction_time = 0
+        temperature_sensor = TemperatureSensor('data/temperature.txt')
+        humidity_sensor = HumiditySensor('data/humidity.txt')
+
         while self.step(self.basic_time_step) != -1:
             # Blink lights
             self.blink_led_lights(led_devices)
@@ -82,16 +123,32 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             # Get battery data
             # print(self.batterySensorGetValue())
 
+            # Do an intensive task
+            # t = IntensiveThread()
+            # t.run()
+
             # Send messages
-            self.send_msg(StringGenerator.get_random_message(4), emitter_devices)
+            transmit_time = self.send_msg(StringGenerator.get_random_message(100), emitter_devices)
+            # print("Transmit time:", transmit_time)
 
             # Receive messages
-            received_messages = self.receive_msgs(receiver_devices)
+            received_messages, receive_time = self.receive_msgs(receiver_devices)
+            # print("Receive time:", receive_time)
+
+            flight_time = cpu_probe.probe_alive_time.get_val()
+            cpu_time = cpu_probe.cpu_time.get_val()
+            io_time = 0 if cpu_probe.io_time.get_val() is None else cpu_probe.io_time.get_val()
+            idle_time = flight_time - (cpu_time + io_time)
+
+            total_energy += flight_time * self.DJI_A3_FC
+            # print("Total energy consumed:", total_energy)
+
+            print('Humidity values', humidity_sensor.get_values())
 
 
 class AutopilotMavic2DJI(AutopilotControlledDrone):
-    def __init__(self, en_devices, nen_devices, motor_devices):
-        super().__init__(en_devices, nen_devices, motor_devices)
+    def __init__(self, devices):
+        super().__init__(devices)
 
     def run(self):
         # Wait a second before starting
